@@ -13,7 +13,8 @@
 #include <QObject>
 #include <QStringList>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class CalendarBase;
 }
 
