@@ -10,7 +10,8 @@
 #include <collection.h>
 #include <item.h>
 
-namespace Helper {
+namespace Helper
+{
 bool confirmExists(const Akonadi::Item &item);
 bool confirmDoesntExist(const Akonadi::Item &item);
 Akonadi::Collection fetchCollection();
