@@ -1,32 +1,20 @@
 /*
-   Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
+   SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef _AKONADI_CALENDAR_CLIPBOARD_H
 #define _AKONADI_CALENDAR_CLIPBOARD_H
 
-#include "calendarbase.h"
 #include "akonadi-calendar_export.h"
+#include "calendarbase.h"
 
-#include <kcalendarcore/incidence.h>
+#include <KCalendarCore/Incidence>
 #include <QObject>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class IncidenceChanger;
 
 /**
@@ -39,11 +27,10 @@ class AKONADI_CALENDAR_EXPORT CalendarClipboard : public QObject
 {
     Q_OBJECT
 public:
-
     enum Mode {
         SingleMode = 0, ///< Only the specified incidence is cut/copied.
-        RecursiveMode,  ///< The specified incidence's children are also cut/copied
-        AskMode         ///< The user is asked if he wants children to be cut/copied too
+        RecursiveMode, ///< The specified incidence's children are also cut/copied
+        AskMode ///< The user is asked if he wants children to be cut/copied too
     };
 
     /**
