@@ -10,17 +10,19 @@
 
 #include <QSortFilterProxyModel>
 
-namespace KCalendarCore {
+namespace KCalendarCore
+{
 class CalFilter;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class CalFilterProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
     explicit CalFilterProxyModel(QObject *parent = nullptr);
-    ~CalFilterProxyModel();
+    ~CalFilterProxyModel() override;
 
     KCalendarCore::CalFilter *filter() const;
     void setFilter(KCalendarCore::CalFilter *filter);
