@@ -6,9 +6,9 @@
 */
 
 #include "fetchjobcalendar.h"
+#include "akonadicalendar_debug.h"
 #include "fetchjobcalendar_p.h"
 #include "incidencefetchjob_p.h"
-#include "akonadicalendar_debug.h"
 #include <collection.h>
 
 using namespace Akonadi;
@@ -18,11 +18,9 @@ FetchJobCalendarPrivate::FetchJobCalendarPrivate(FetchJobCalendar *qq)
     : CalendarBasePrivate(qq)
     , q(qq)
 {
-    auto *job = new IncidenceFetchJob();
-    connect(job, &KJob::result,
-            this, &FetchJobCalendarPrivate::slotSearchJobFinished);
-    connect(this, &CalendarBasePrivate::fetchFinished,
-            this, &FetchJobCalendarPrivate::slotFetchJobFinished);
+    auto job = new IncidenceFetchJob();
+    connect(job, &KJob::result, this, &FetchJobCalendarPrivate::slotSearchJobFinished);
+    connect(this, &CalendarBasePrivate::fetchFinished, this, &FetchJobCalendarPrivate::slotFetchJobFinished);
 }
 
 FetchJobCalendarPrivate::~FetchJobCalendarPrivate()
@@ -31,7 +29,7 @@ FetchJobCalendarPrivate::~FetchJobCalendarPrivate()
 
 void FetchJobCalendarPrivate::slotSearchJobFinished(KJob *job)
 {
-    auto *searchJob = static_cast<Akonadi::IncidenceFetchJob *>(job);
+    auto searchJob = static_cast<Akonadi::IncidenceFetchJob *>(job);
     m_success = true;
     m_errorMessage = QString();
     if (searchJob->error()) {
@@ -60,8 +58,7 @@ void FetchJobCalendarPrivate::slotFetchJobFinished()
 {
     m_isLoaded = true;
     // Q_EMIT loadFinished() in a delayed manner, due to freezes because of execs.
-    QMetaObject::invokeMethod(q, "loadFinished", Qt::QueuedConnection,
-                              Q_ARG(bool, m_success), Q_ARG(QString, m_errorMessage));
+    QMetaObject::invokeMethod(q, "loadFinished", Qt::QueuedConnection, Q_ARG(bool, m_success), Q_ARG(QString, m_errorMessage));
 }
 
 FetchJobCalendar::FetchJobCalendar(QObject *parent)
@@ -75,7 +72,7 @@ FetchJobCalendar::~FetchJobCalendar()
 
 bool FetchJobCalendar::isLoaded() const
 {
-    auto *d = static_cast<FetchJobCalendarPrivate *>(d_ptr.data());
+    auto d = static_cast<FetchJobCalendarPrivate *>(d_ptr.data());
     return d->m_isLoaded;
 }
 
